==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersKeywordArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersKeywordArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property value A value for the keyword.
 */
public data class InsightFiltersKeywordArgs(
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersKeywordArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersKeywordArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersKeywordArgs.builder()
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersKeywordArgs].
 */
@PulumiTagMarker
public class InsightFiltersKeywordArgsBuilder internal constructor() {
    private var `value`: Output<String>? = null

    /**
     * @param value A value for the keyword.
     */
    @JvmName("nkgdvyjxuwxwiyng")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value A value for the keyword.
     */
    @JvmName("mpoeeljxsnqdrobu")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): InsightFiltersKeywordArgs = InsightFiltersKeywordArgs(
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/securityhub/kotlin/inputs/InsightFiltersKeywordArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.securityhub.kotlin.inputs

import com.pulumi.aws.securityhub.inputs.InsightFiltersKeywordArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property value A value for the keyword.
 */
public data class InsightFiltersKeywordArgs(
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.securityhub.inputs.InsightFiltersKeywordArgs> {
    override fun toJava(): com.pulumi.aws.securityhub.inputs.InsightFiltersKeywordArgs =
        com.pulumi.aws.securityhub.inputs.InsightFiltersKeywordArgs.builder()
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InsightFiltersKeywordArgs].
 */
@PulumiTagMarker
public class InsightFiltersKeywordArgsBuilder internal constructor() {
    private var `value`: Output<String>? = null

    /**
     * @param value A value for the keyword.
     */
    @JvmName("tdfmfwoysbxflthb")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value A value for the keyword.
     */
    @JvmName("vmscpgahnpkgmahh")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): InsightFiltersKeywordArgs = InsightFiltersKeywordArgs(
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}
